@@ -2,7 +2,9 @@ package IO::Die;
 
 use 5.006;
 use strict;
-use warnings;
+
+#not in production
+#use warnings;
 
 =head1 NAME
 
@@ -10,11 +12,11 @@ IO::Die - Namespaced, error-checked I/O
 
 =head1 VERSION
 
-Version 0.022
+Version 0.024
 
 =cut
 
-our $VERSION = '0.022';
+our $VERSION = '0.024';
 
 #----------------------------------------------------------------------
 #PROTECTED
@@ -882,7 +884,10 @@ from that module that you may appreciate:
 * C<IO::Die> does not use function prototypes and does not export:
 all calls into C<IO::Die> (or subclasses) “look like” what they are.
 
-* C<IO::Die> is much lighter than C<autodie>!
+* C<IO::Die> does not try to impose its own error handling; you can customize
+both how to represent errors and what to do with them.
+
+* C<IO::Die> seems lighter than C<autodie> in simple memory usage checks. YMMV.
 
 For the most part, you can simply replace:
 
@@ -1132,6 +1137,14 @@ L<https://github.com/FGasper/io-die>
 
 Open an issue at the GitHub URL above. Patches are welcome!
 
+=head1 TODO
+
+=over 4
+
+=item * More tests, especially for socket functions.
+
+=back
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
